@@ -36,7 +36,9 @@ tracker_miner_test_init (TrackerMinerTest *miner)
 TrackerMiner *
 tracker_miner_test_new (const gchar *name)
 {
-	return g_object_new (TRACKER_TYPE_MINER_TEST,
-	                     "name", name,
-	                     NULL);
+	return g_initable_new (TRACKER_TYPE_MINER_TEST,
+	                       NULL,
+	                       NULL,
+	                       "name", name,
+	                       NULL);
 }
