@@ -45,6 +45,8 @@ gchar *  tracker_strhex                     (const guint8 *data,
                                              gchar         delimiter);
 gchar *  tracker_utf8_truncate              (const gchar  *str,
                                              gsize         max_size);
+gchar *  tracker_unescape_unichars          (const gchar  *str,
+					     gssize        len);
 
 G_END_DECLS
 
