@@ -69,6 +69,8 @@ TrackerDataManager * tracker_data_manager_new        (TrackerDBManagerFlags   fl
                                                       guint                   select_cache_size,
                                                       guint                   update_cache_size);
 
+void                 tracker_data_manager_shutdown            (TrackerDataManager *manager);
+
 GFile *              tracker_data_manager_get_cache_location  (TrackerDataManager *manager);
 GFile *              tracker_data_manager_get_data_location   (TrackerDataManager *manager);
 TrackerDBJournal *   tracker_data_manager_get_journal_writer  (TrackerDataManager *manager);
@@ -77,11 +79,14 @@ TrackerOntologies *  tracker_data_manager_get_ontologies      (TrackerDataManage
 
 TrackerDBManager *   tracker_data_manager_get_db_manager      (TrackerDataManager *manager);
 TrackerDBInterface * tracker_data_manager_get_db_interface    (TrackerDataManager *manager);
+TrackerDBInterface * tracker_data_manager_get_writable_db_interface (TrackerDataManager *manager);
 TrackerData *        tracker_data_manager_get_data            (TrackerDataManager *manager);
 
 gboolean tracker_data_manager_init_fts               (TrackerDBInterface     *interface,
 						      gboolean                create);
 
+GHashTable *         tracker_data_manager_get_namespaces      (TrackerDataManager *manager);
+
 G_END_DECLS
 
 #endif /* __LIBTRACKER_DATA_MANAGER_H__ */
