@@ -94,20 +94,28 @@ sql_by_query (void)
 	TrackerDBStatement *stmt;
 	TrackerDBCursor *cursor = NULL;
 	GError *error = NULL;
-	gboolean first_time = FALSE;
 	gint n_rows = 0;
+	GFile *cache_location, *data_location, *ontology_location;
+	TrackerDataManager *data_manager;
+	gchar *dir;
 
-	if (!tracker_data_manager_init (0,
-	                                NULL,
-	                                &first_time,
-	                                FALSE,
-	                                FALSE,
-	                                100,
-	                                100,
-	                                NULL,
-	                                NULL,
-	                                NULL,
-	                                &error)) {
+	dir = g_build_filename (g_get_user_cache_dir (), "tracker", NULL);
+	cache_location = g_file_new_for_path (dir);
+	g_free (dir);
+
+	dir = g_build_filename (g_get_user_data_dir (), "tracker", "data", NULL);
+	data_location = g_file_new_for_path (dir);
+	g_free (dir);
+
+	dir = g_build_filename (SHAREDIR, "tracker", "ontologies", "nepomuk", NULL);
+	ontology_location = g_file_new_for_path (dir);
+	g_free (dir);
+
+	data_manager = tracker_data_manager_new (0, cache_location,
+	                                         data_location, ontology_location,
+	                                         FALSE, FALSE, 100, 100);
+
+	if (!g_initable_init (G_INITABLE (data_manager), NULL, &error)) {
 		g_printerr ("%s: %s\n",
 		            _("Failed to initialize data manager"),
 		            error->message);
@@ -118,7 +126,7 @@ sql_by_query (void)
 	g_print ("--------------------------------------------------\n");
 	g_print ("\n\n");
 
-	iface = tracker_db_manager_get_db_interface ();
+	iface = tracker_data_manager_get_db_interface (data_manager);
 
 	stmt = tracker_db_interface_create_statement (iface, TRACKER_DB_STATEMENT_CACHE_TYPE_NONE, &error, "%s", query);
 
