@@ -32,10 +32,14 @@ typedef struct {
 	const gchar *query;
 } AsyncData;
 
+typedef struct {
+} DataFixture;
+
 static TrackerSparqlConnection *connection;
 
 static void
-delete_test_data ()
+delete_test_data (DataFixture   *fixture,
+                  gconstpointer  user_data)
 {
 	GError *error = NULL;
 	const char *delete_query = "DELETE { "
@@ -50,14 +54,15 @@ delete_test_data ()
 }
 
 static void
-insert_test_data ()
+insert_test_data (DataFixture   *fixture,
+                  gconstpointer  user_data)
 {
 	GError *error = NULL;
 	char *longName = g_malloc (LONG_NAME_SIZE);
 	char *filled_query;
 
 	/* Ensure data is deleted */
-	delete_test_data ();
+	delete_test_data (fixture, user_data);
 
 	memset (longName, 'a', LONG_NAME_SIZE);
 
@@ -182,19 +187,23 @@ query_and_compare_results (const char *query)
 }
 
 static void
-test_tracker_sparql_query_iterate () {
+test_tracker_sparql_query_iterate (DataFixture  *fixture,
+                                   gconstpointer user_data)
+{
 	query_and_compare_results ("SELECT ?r nie:url(?r) WHERE {?r a nfo:FileDataObject}");
 }
 
 static void
-test_tracker_sparql_query_iterate_largerow ()
+test_tracker_sparql_query_iterate_largerow (DataFixture  *fixture,
+                                            gconstpointer user_data)
 {
 	query_and_compare_results ("SELECT nao:identifier(?r) WHERE {?r a nmm:Photo}");
 }
 
 /* Runs an invalid query */
 static void
-test_tracker_sparql_query_iterate_error ()
+test_tracker_sparql_query_iterate_error (DataFixture  *fixture,
+                                         gconstpointer user_data)
 {
 	TrackerSparqlCursor *cursor;
 	GError *error = NULL;
@@ -218,7 +227,8 @@ test_tracker_sparql_query_iterate_error ()
 
 /* Runs a query returning an empty set */
 static void
-test_tracker_sparql_query_iterate_empty_subprocess ()
+test_tracker_sparql_query_iterate_empty_subprocess (DataFixture  *fixture,
+                                                    gconstpointer user_data)
 {
 	TrackerSparqlCursor *cursor;
 	GError *error = NULL;
@@ -238,7 +248,8 @@ test_tracker_sparql_query_iterate_empty_subprocess ()
 }
 
 static void
-test_tracker_sparql_query_iterate_empty ()
+test_tracker_sparql_query_iterate_empty (DataFixture  *fixture,
+                                         gconstpointer user_data)
 {
 	TrackerSparqlCursor *cursor;
 	GError *error = NULL;
@@ -262,7 +273,8 @@ test_tracker_sparql_query_iterate_empty ()
 
 /* Closes the cursor before all results are read */
 static void
-test_tracker_sparql_query_iterate_sigpipe ()
+test_tracker_sparql_query_iterate_sigpipe (DataFixture  *fixture,
+                                           gconstpointer user_data)
 {
 	TrackerSparqlCursor *cursor;
 	GError *error = NULL;
@@ -279,7 +291,8 @@ test_tracker_sparql_query_iterate_sigpipe ()
 }
 
 static void
-test_tracker_sparql_update_fast_small ()
+test_tracker_sparql_update_fast_small (DataFixture  *fixture,
+                                       gconstpointer user_data)
 {
 	GError *error = NULL;
 	const gchar *query = "INSERT { _:x a nmo:Message }";
@@ -290,7 +303,8 @@ test_tracker_sparql_update_fast_small ()
 }
 
 static void
-test_tracker_sparql_update_fast_large ()
+test_tracker_sparql_update_fast_large (DataFixture  *fixture,
+                                       gconstpointer user_data)
 {
 	GError *error = NULL;
 	gchar *lots;
@@ -340,7 +354,8 @@ async_update_array_callback (GObject      *source_object,
 
 
 static void
-test_tracker_sparql_update_array_async (void)
+test_tracker_sparql_update_array_async (DataFixture   *fixture,
+                                        gconstpointer  user_data)
 {
 	const gchar *queries[6] = { "INSERT { _:a a nmo:Message }",
 	                            "INSERT { _:b a nmo:Message }",
@@ -374,7 +389,8 @@ test_tracker_sparql_update_array_async (void)
 }
 
 static void
-test_tracker_sparql_update_fast_error ()
+test_tracker_sparql_update_fast_error (DataFixture  *fixture,
+                                       gconstpointer user_data)
 {
 	GError *error = NULL;
 	const gchar *query = "blork blork blork";
@@ -386,7 +402,8 @@ test_tracker_sparql_update_fast_error ()
 }
 
 static void
-test_tracker_sparql_update_blank_fast_small ()
+test_tracker_sparql_update_blank_fast_small (DataFixture  *fixture,
+                                             gconstpointer user_data)
 {
 	GError *error = NULL;
 	const gchar *query = "INSERT { _:x a nmo:Message }";
@@ -401,7 +418,8 @@ test_tracker_sparql_update_blank_fast_small ()
 }
 
 static void
-test_tracker_sparql_update_blank_fast_large ()
+test_tracker_sparql_update_blank_fast_large (DataFixture  *fixture,
+                                             gconstpointer user_data)
 {
 	GError *error = NULL;
 	gchar *lots;
@@ -426,7 +444,8 @@ test_tracker_sparql_update_blank_fast_large ()
 }
 
 static void
-test_tracker_sparql_update_blank_fast_error (void)
+test_tracker_sparql_update_blank_fast_error (DataFixture  *fixture,
+                                             gconstpointer user_data)
 {
 	GError *error = NULL;
 	const gchar *query = "blork blork blork";
@@ -441,7 +460,8 @@ test_tracker_sparql_update_blank_fast_error (void)
 }
 
 static void
-test_tracker_sparql_update_blank_fast_no_blanks (void)
+test_tracker_sparql_update_blank_fast_no_blanks (DataFixture  *fixture,
+                                                 gconstpointer user_data)
 {
 	GError *error = NULL;
 	const gchar *query = "INSERT { <urn:not_blank> a nmo:Message }";
@@ -456,7 +476,8 @@ test_tracker_sparql_update_blank_fast_no_blanks (void)
 }
 
 static void
-test_tracker_batch_sparql_update_fast (void)
+test_tracker_batch_sparql_update_fast (DataFixture  *fixture,
+                                       gconstpointer user_data)
 {
 	/* GError *error = NULL; */
 	/* const gchar *query = "INSERT { _:x a nmo:Message }"; */
@@ -504,7 +525,8 @@ async_query_cb (GObject      *source_object,
 }
 
 static void
-test_tracker_sparql_query_iterate_async (void)
+test_tracker_sparql_query_iterate_async (DataFixture  *fixture,
+                                         gconstpointer user_data)
 {
 	const gchar *query = "SELECT ?r nie:url(?r) WHERE {?r a nfo:FileDataObject}";
 	GMainLoop *main_loop;
@@ -545,7 +567,8 @@ cancel_query_cb (GObject      *source_object,
 }
 
 static void
-test_tracker_sparql_query_iterate_async_cancel (void)
+test_tracker_sparql_query_iterate_async_cancel (DataFixture  *fixture,
+                                                gconstpointer user_data)
 {
 	const gchar *query = "SELECT ?r nie:url(?r) WHERE {?r a nfo:FileDataObject}";
 	GMainLoop *main_loop;
@@ -582,7 +605,8 @@ async_update_callback (GObject      *source_object,
 }
 
 static void
-test_tracker_sparql_update_async (void)
+test_tracker_sparql_update_async (DataFixture  *fixture,
+                                  gconstpointer user_data)
 {
 	const gchar *query = "INSERT { _:x a nmo:Message }";
 	GMainLoop *main_loop;
@@ -623,7 +647,8 @@ cancel_update_cb (GObject      *source_object,
 }
 
 static void
-test_tracker_sparql_update_async_cancel (void)
+test_tracker_sparql_update_async_cancel (DataFixture  *fixture,
+                                         gconstpointer user_data)
 {
 	GCancellable *cancellable = g_cancellable_new ();
 	const gchar *query = "INSERT { _:x a nmo:Message }";
@@ -662,7 +687,8 @@ async_update_blank_callback (GObject      *source_object,
 }
 
 static void
-test_tracker_sparql_update_blank_async (void)
+test_tracker_sparql_update_blank_async (DataFixture *fixture,
+                                        gconstpointer user_data)
 {
 	const gchar *query = "INSERT { _:x a nmo:Message }";
 	GMainLoop *main_loop;
@@ -698,30 +724,46 @@ main (gint argc, gchar **argv)
 
 	connection = tracker_sparql_connection_get (NULL, NULL);
 
-	insert_test_data ();
-
-	g_test_add_func ("/steroids/tracker/tracker_sparql_query_iterate", test_tracker_sparql_query_iterate);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_query_iterate_largerow", test_tracker_sparql_query_iterate_largerow);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_query_iterate_error", test_tracker_sparql_query_iterate_error);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_query_iterate_empty", test_tracker_sparql_query_iterate_empty);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_query_iterate_empty/subprocess", test_tracker_sparql_query_iterate_empty_subprocess);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_query_iterate_sigpipe", test_tracker_sparql_query_iterate_sigpipe);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_fast_small", test_tracker_sparql_update_fast_small);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_fast_large", test_tracker_sparql_update_fast_large);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_fast_error", test_tracker_sparql_update_fast_error);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_blank_fast_small", test_tracker_sparql_update_blank_fast_small);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_blank_fast_large", test_tracker_sparql_update_blank_fast_large);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_blank_fast_error", test_tracker_sparql_update_blank_fast_error);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_blank_fast_no_blanks", test_tracker_sparql_update_blank_fast_no_blanks);
-	g_test_add_func ("/steroids/tracker/tracker_batch_sparql_update_fast", test_tracker_batch_sparql_update_fast);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_query_iterate_async", test_tracker_sparql_query_iterate_async);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_query_iterate_async_cancel", test_tracker_sparql_query_iterate_async_cancel);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_async", test_tracker_sparql_update_async);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_async_cancel", test_tracker_sparql_update_async_cancel);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_blank_async", test_tracker_sparql_update_blank_async);
-	g_test_add_func ("/steroids/tracker/tracker_sparql_update_array_async", test_tracker_sparql_update_array_async);
-
-	delete_test_data ();
+	g_test_add ("/steroids/tracker/tracker_sparql_query_iterate", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_query_iterate, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_query_iterate_largerow", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_query_iterate_largerow, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_query_iterate_error", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_query_iterate_error, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_query_iterate_empty", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_query_iterate_empty, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_query_iterate_empty/subprocess", DataFixture, NULL,
+			insert_test_data, test_tracker_sparql_query_iterate_empty_subprocess, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_query_iterate_sigpipe", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_query_iterate_sigpipe, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_fast_small", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_fast_small, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_fast_large", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_fast_large, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_fast_error", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_fast_error, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_blank_fast_small", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_blank_fast_small, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_blank_fast_large", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_blank_fast_large, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_blank_fast_error", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_blank_fast_error, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_blank_fast_no_blanks", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_blank_fast_no_blanks, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_batch_sparql_update_fast", DataFixture, NULL, insert_test_data,
+			test_tracker_batch_sparql_update_fast, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_query_iterate_async", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_query_iterate_async, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_query_iterate_async_cancel", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_query_iterate_async_cancel, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_async", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_async, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_async_cancel", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_async_cancel, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_blank_async", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_blank_async, delete_test_data);
+	g_test_add ("/steroids/tracker/tracker_sparql_update_array_async", DataFixture, NULL, insert_test_data,
+			test_tracker_sparql_update_array_async, delete_test_data);
 
 	return g_test_run ();
 }
